@@ -24,7 +24,7 @@ NULL
 
 get_bike_sharing_task = function() {
   b = as_backend("bike_sharing")
-  task = mlr3::TaskRegr$new("bike_sharing", b, target = "count")
+  task = mlr3::TaskRegr$new("bike_sharing", b, target = "count", label = "Bike Sharing Demand")
   b$hash = task$man = "mlr3data::mlr_tasks_bike_sharing"
   task
 }
